@@ -8,7 +8,7 @@
     *   SPDX-License-Identifier: GPL-3.0-or-later
     */
 .pragma library
-.import QtQuick 2.12 as Quick
+.import QtQuick as Quick
 .import core 1.0 as GCompris
 .import "qrc:/gcompris/src/core/core.js" as Core
 
