@@ -8,7 +8,7 @@
  *   SPDX-License-Identifier: GPL-3.0-or-later
  */
 .pragma library
-.import QtQuick 2.12 as Quick
+.import QtQuick as Quick
 .import "qrc:/gcompris/src/core/core.js" as Core
 .import "engine.js" as Engine
 
@@ -229,7 +229,7 @@ function undo() {
         move = state.undo();
         redo_stack.push(move)
     }
-    items.redo_stack = redo_stack
+    items.redo_stack = [...redo_stack]
     refresh()
 }
 
@@ -254,8 +254,7 @@ function redo() {
     }
 
     // Force refresh
-    items.redo_stack = []
-    items.redo_stack = redo_stack
+    items.redo_stack = [...redo_stack]
     clearAcceptMove()
 }
 
