@@ -9,12 +9,10 @@
  *   SPDX-License-Identifier: GPL-3.0-or-later
  */
 .pragma library
-.import QtQuick 2.12 as Quick
+.import QtQuick as Quick
 .import core 1.0 as GCompris
 .import "qrc:/gcompris/src/core/core.js" as Core
 
-var url = "qrc:/gcompris/src/activities/followline/resource/"
-
 var numberOfLevel = 8
 var items
 var createdLineParts
