@@ -6,7 +6,7 @@
  * SPDX-License-Identifier: GPL-3.0-or-later
  */
 .pragma library
-.import QtQuick 2.12 as Quick
+.import QtQuick as Quick
 .import "qrc:/gcompris/src/core/core.js" as Core
 
 var numberOfLevel;
@@ -30,15 +30,17 @@ function initLevel() {
     items.score.currentSubLevel = 0;
     items.errorRectangle.resetState();
 
-    items.numberOfSubLevels = levels[items.currentLevel].length;
+    items.numberOfSubLevels = levels[items.currentLevel].subLevels.length;
 
-    Core.shuffle(levels[items.currentLevel]);
+    if(levels[items.currentLevel].shuffle) {
+        Core.shuffle(levels[items.currentLevel].subLevels);
+    }
 
     initSubLevel();
 }
 
 function initSubLevel() {
-    var currentSubLevel = levels[items.currentLevel][items.score.currentSubLevel];
+    var currentSubLevel = levels[items.currentLevel].subLevels[items.score.currentSubLevel];
     items.chartType = currentSubLevel.chartType;
 
     items.fixedNumerator = currentSubLevel.fixedNumerator ? currentSubLevel.fixedNumerator : false;
@@ -83,6 +85,7 @@ function initSubLevel() {
 
     items.chartItem.initLevel();
     items.buttonsBlocked = false;
+    items.client.startTiming(); // for server version
 }
 
 function nextLevel() {
@@ -112,10 +115,12 @@ function goodAnswer() {
     items.score.currentSubLevel++;
     items.score.playWinAnimation();
     items.goodAnswerSound.play();
+    items.client.sendToServer(true);
 }
 
 function badAnswer() {
     items.buttonsBlocked = true;
     items.errorRectangle.startAnimation();
     items.badAnswerSound.play();
+    items.client.sendToServer(false);
 }
