@@ -29,7 +29,7 @@
  */
 
 .pragma library
-.import QtQuick 2.12 as Quick
+.import QtQuick as Quick
 .import core 1.0 as GCompris
 .import "qrc:/gcompris/src/core/core.js" as Core
 
