@@ -13,7 +13,7 @@
  */
 
 .pragma library
-.import QtQuick 2.12 as Quick
+.import QtQuick as Quick
 .import core 1.0 as GCompris //for ApplicationInfo
 .import "qrc:/gcompris/src/core/core.js" as Core
 .import "qrc:/gcompris/src/activities/lang/lang_api.js" as Lang
