@@ -9,7 +9,7 @@
  *   SPDX-License-Identifier: GPL-3.0-or-later
  */
 .pragma library
-.import QtQuick 2.12 as Quick
+.import QtQuick as Quick
 .import "qrc:/gcompris/src/core/core.js" as Core
 .import core 1.0 as GCompris //for ApplicationInfo
 .import "qrc:/gcompris/src/activities/lang/lang_api.js" as Lang
