@@ -10,7 +10,7 @@
  *   SPDX-License-Identifier: GPL-3.0-or-later
  */
 .pragma library
-.import QtQuick 2.12 as Quick
+.import QtQuick as Quick
 .import core 1.0 as GCompris //for ApplicationInfo
 .import "qrc:/gcompris/src/core/core.js" as Core
 
@@ -58,6 +58,7 @@ function initLevel() {
     placeFishToReach()
     moveTuxToIceBlock()
     items.clockPosition = 4
+    items.client.startTiming()      // for server version.
 }
 
 function moveTux(numberOfMovesToDo) {
@@ -66,7 +67,8 @@ function moveTux(numberOfMovesToDo) {
     if(items.chooseDiceBar.value1 === 0 && items.chooseDiceBar.value2 === 0) {
         return
     }
-    else if (tuxIceBlockNumberGoal != fishIndex) {
+    items.client.sendToServer(tuxIceBlockNumberGoal === fishIndex)  // for server version.
+    if (tuxIceBlockNumberGoal !== fishIndex) {
         items.clockPosition--
         items.badAnswerSound.play()
         if (items.clockPosition === 0) {
