@@ -5,7 +5,7 @@
  *
  */
 .pragma library
-.import QtQuick 2.12 as Quick
+.import QtQuick as Quick
 .import "qrc:/gcompris/src/core/core.js" as Core
 
 var numberOfLevel = 4
