@@ -48,7 +48,9 @@ function calcDigitCount() {
 function buildNumbersModel() {
     items.numbersModel.clear()
     items.board.digitCount = Math.max(items.nbDigits, calcDigitCount(values))
-    if(items.operation === items.operationType.Addition) {
+    var needExtraColumn = false
+    if(items.operation === items.operationType.Addition && (items.withCarry || level.doItYourself)) {
+        needExtraColumn = true
         items.board.digitCount += 1     // add 1 slot for additions as the final sum can have one more digit
     }
     operationString = ""
@@ -57,6 +59,7 @@ function buildNumbersModel() {
         items.numbersModel.append({ "value_" :  values[i]
                                   , "digitCount_" : items.board.digitCount
                                   , "operator_" : operators[i]
+                                  , "restrictHighestColumn_": needExtraColumn
                                   })
         operationString += i ? ` ${operators[i]} ${values[i]}` : values[i]
         if (i > 0) {
@@ -66,7 +69,12 @@ function buildNumbersModel() {
     items.board.result = result
     items.resultNumber.numberValue = ""
     if (level.doItYourself) {
-        items.caption.text = level.title
+        if(items.operation === items.operationType.Addition) {
+            items.caption.text = items.createAdditionText
+        } else {
+            items.caption.text = items.createSubtractionText
+        }
+
     } else {
         items.caption.text = (!items.alreadyLaid ? qsTr("Write:") : qsTr("Solve:")) + " " + operationString
     }
@@ -136,9 +144,20 @@ function checkDropped() {
     }
     items.inputLocked = true
     var ok = true
+    var isNegative = false
     if (level.doItYourself) {
-        for (var i = 0; i < items.numbersModel.count; i++)      // Copy value to expected
-            items.numberRepeater.itemAt(i).copyDroppedValues()
+        var notEmptyLines = 0
+        for (var i = 0; i < items.numbersModel.count; i++) {
+            if(!items.numberRepeater.itemAt(i).checkEmptyNumber()) {
+                notEmptyLines++
+            }
+            items.numberRepeater.itemAt(i).copyDroppedValues()  // Copy value to expected
+        }
+        if(notEmptyLines < 2) {    // if not at least 2 lines, stop here
+            items.errorRectangle.startAnimation()
+            items.crashSound.play()
+            return
+        }
         for (i = 0; i < items.numbersModel.count; i++)          // Check for valid lines
             ok = ok && items.numberRepeater.itemAt(i).checkEmptyDigit()
         if (ok) {
@@ -150,8 +169,10 @@ function checkDropped() {
                     result += (((i === 0) || (items.operation === items.operationType.Addition)) ? 1 : -1) * value
             }
             items.board.result = result
-            if (result < 0)
+            if (result < 0) {
                 ok = false
+                isNegative = true
+            }
         }
     } else {
         for (i = 0; i < items.numbersModel.count; i++)          // Check for valid lines
@@ -170,7 +191,11 @@ function checkDropped() {
         items.okButton.visible = true
         items.inputLocked = false
     } else {
-        items.errorRectangle.startAnimation();
+        if(isNegative) {
+            items.negativeNumberWarning.visible = true
+        } else {
+            items.errorRectangle.startAnimation()
+        }
         items.crashSound.play()
     }
 }
@@ -200,6 +225,8 @@ function checkResult() {
         if (item.value === -1)                                          // Detect first non zero value. After empty digit are not allowed
             zeros = false
     }
+
+    items.client.sendToServer(ok)
     if (ok) {
         items.currentSubLevel++
         items.score.playWinAnimation()
@@ -217,9 +244,15 @@ function initLevel() {
         level.doItYourself = false
     items.subLevelCount = level.nbSubLevel
     items.nbLines = level.nbLines
-    items.nbDigits= level.nbDigits
-    items.withCarry= level.withCarry
-    items.alreadyLaid= level.alreadyLaid
+    items.nbDigits = level.nbDigits
+    // In doItYourself mode, explicitely use withCarry and not alreadyLaid
+    if(level.doItYourself) {
+        items.withCarry = true
+        items.alreadyLaid = false
+    } else {
+        items.withCarry = level.withCarry
+        items.alreadyLaid = level.alreadyLaid
+    }
     if (items.withCarry)
         randomValues()
     else
@@ -229,6 +262,8 @@ function initLevel() {
     items.resultNumber.numberValue = "0"
     items.okButton.visible = items.alreadyLaid ? true : false
     items.inputLocked = false
+
+    items.client.startTiming()
 }
 
 function nextLevel() {
