@@ -9,6 +9,7 @@
  */
 #include "ActivityInfo.h"
 
+#include <QDir>
 #include <QFile>
 #include <QtDebug>
 #include <QQmlProperty>
@@ -24,7 +25,8 @@ ActivityInfo::ActivityInfo(QObject *parent) :
     m_maximalDifficulty(0),
     m_favorite(false),
     m_enabled(true),
-    m_createdInVersion(0)
+    m_createdInVersion(0),
+    m_acceptDataset(false)
 {
 }
 
@@ -37,13 +39,9 @@ void ActivityInfo::setName(const QString &name)
 {
     m_name = name;
     // Once we are given a name, we can get the favorite property
-    // from the persistant configuration
+    // from the persistent configuration
     m_favorite = ApplicationSettings::getInstance()->isFavorite(m_name);
 
-    if(!m_levels.empty()) {
-        setCurrentLevels();
-    }
-
     Q_EMIT nameChanged();
 }
 
@@ -205,18 +203,47 @@ QStringList ActivityInfo::levels() const
 
 void ActivityInfo::setLevels(const QStringList &levels)
 {
+    m_acceptDataset = true;
     m_levels = levels;
-    setCurrentLevels();
 
     Q_EMIT levelsChanged();
 }
 
 void ActivityInfo::fillDatasets(QQmlEngine *engine)
 {
+    /* If we switch from a previous version to one above or equals to 26.0
+       we need to fill the ignoredLevels from the list of currentLevels stored
+       in configuration.
+       The currentLevels was previously used because we could not add external
+       datasets (but with this approach we cannot disable them, thus we change
+       to a list of ignored instead of currently used).
+    */
+    if (ApplicationSettings::getInstance()->getUpdateToNewIgnoreLevels()) {
+        QStringList currentLevelsInConf = ApplicationSettings::getInstance()->currentLevels(m_name);
+        if (!currentLevelsInConf.empty()) {
+            for (const QString &level: m_levels) {
+                if (!currentLevelsInConf.contains(level)) {
+                    m_ignoredLevels << level;
+                }
+            }
+        }
+        if (!m_ignoredLevels.empty()) {
+            ApplicationSettings::getInstance()->setIgnoredLevels(m_name.split('/')[0], m_ignoredLevels);
+        }
+    }
+
+    m_ignoredLevels = ApplicationSettings::getInstance()->ignoredLevels(m_name.split('/')[0]);
     quint32 levelMin = ApplicationSettings::getInstance()->filterLevelMin();
     quint32 levelMax = ApplicationSettings::getInstance()->filterLevelMax();
     for (const QString &level: std::as_const(m_levels)) {
         QString url = QString("qrc:/gcompris/src/activities/%1/resource/%2/Data.qml").arg(m_name.split('/')[0], level);
+
+        if (!QFileInfo::exists(url.sliced(3))) {
+            qDebug() << "INFO: did not find level" << url.sliced(3) << "internally";
+            removeDataset(level);
+            continue;
+        }
+
         QQmlComponent componentRoot(engine, QUrl(url));
         QObject *objectRoot = componentRoot.create();
         if (objectRoot != nullptr) {
@@ -231,6 +258,42 @@ void ActivityInfo::fillDatasets(QQmlEngine *engine)
             qDebug() << "ERROR: failed to load " << m_name << " " << componentRoot.errors();
         }
     }
+
+    // Load user created levels
+    bool atLeastOneLevelAdded = false;
+    QStringList externalLevels;
+    const QString userDatasetPath(QStandardPaths::writableLocation(QStandardPaths::AppDataLocation) + "/" + m_name.split('/')[0]);
+    QDir userDatasetFolder(userDatasetPath);
+    userDatasetFolder.setFilter(QDir::Dirs | QDir::NoSymLinks | QDir::NoDotAndDotDot);
+    QFileInfoList datasetList = userDatasetFolder.entryInfoList();
+    for (const QFileInfo &datasetFileInfo: datasetList) {
+        QString url = QString("%1/Data.qml").arg(datasetFileInfo.absoluteFilePath());
+        QQmlComponent componentRoot(engine, QUrl(url));
+        QObject *objectRoot = componentRoot.create();
+        if (objectRoot != nullptr) {
+            Dataset *dataset = qobject_cast<Dataset *>(objectRoot);
+            QString datasetName(datasetFileInfo.fileName());
+
+            if (levelMin > dataset->difficulty() || levelMax < dataset->difficulty()) {
+                dataset->setEnabled(false);
+            }
+            externalLevels.push_back(datasetName);
+            addDataset(datasetName, dataset);
+            atLeastOneLevelAdded = true;
+        }
+        else {
+            qDebug() << "ERROR: failed to load " << m_name << " " << componentRoot.errors();
+        }
+    }
+    // The sortLevels function in core.js expects to first sort external levels, then internal ones, so we put here the external levels at the beginning too
+    externalLevels.append(m_levels);
+    m_levels = externalLevels;
+
+    if (atLeastOneLevelAdded) {
+        Q_EMIT levelsChanged();
+    }
+
+    setCurrentLevels();
     if (m_levels.empty()) {
         setMinimalDifficulty(m_difficulty);
         setMaximalDifficulty(m_difficulty);
@@ -240,6 +303,15 @@ void ActivityInfo::fillDatasets(QQmlEngine *engine)
     }
 }
 
+void ActivityInfo::removeDataset(const QString &datasetName)
+{
+    m_currentLevels.removeOne(datasetName);
+    m_levels.removeOne(datasetName);
+    delete m_datasets[datasetName];
+    m_datasets.remove(datasetName);
+    Q_EMIT currentLevelsChanged();
+}
+
 QStringList ActivityInfo::currentLevels() const
 {
     return m_currentLevels;
@@ -275,34 +347,29 @@ void ActivityInfo::setCurrentLevels(const QStringList &currentLevels)
 void ActivityInfo::setCurrentLevels()
 {
     if (!m_name.isEmpty()) {
-        // by default, activate all existing levels
-        if (!m_levels.empty() && ApplicationSettings::getInstance()->currentLevels(m_name).empty()) {
-            ApplicationSettings::getInstance()->setCurrentLevels(m_name, m_levels);
+        m_ignoredLevels = ApplicationSettings::getInstance()->ignoredLevels(m_name.split('/')[0]);
+        // Clear m_currentLevels before filling it to avoid duplicates when reloading it after sending new level from the server
+        m_currentLevels.clear();
+        // Fill m_currentLevels with all levels except the ignored ones
+        for (const QString &level: m_levels) {
+            if (!m_ignoredLevels.contains(level)) {
+                m_currentLevels << level;
+            }
         }
-        m_currentLevels = ApplicationSettings::getInstance()->currentLevels(m_name);
     }
     else {
         qWarning() << "ActivityInfo::setCurrentLevels(), name is empty";
     }
-    // Remove levels that could have been added in the configuration but are not existing
-    // Either we rename a dataset, or after working in another branch to add dataset and switching to a branch without it
-    QStringList levelsToRemove;
-    for (const QString &level: std::as_const(m_currentLevels)) {
-        if (!m_levels.contains(level)) {
-            qDebug() << QString("Invalid level %1 for activity %2, removing it").arg(level, m_name);
-            levelsToRemove << level;
-        }
-    }
-    for (const QString &level: std::as_const(levelsToRemove)) {
-        m_currentLevels.removeOne(level);
-    }
+
     computeMinMaxDifficulty();
+
+    Q_EMIT currentLevelsChanged();
 }
 
 void ActivityInfo::enableDatasetsBetweenDifficulties(quint32 levelMin, quint32 levelMax)
 {
     QStringList newLevels;
-    for (const auto& [key, dataset]: m_datasets.asKeyValueRange()) {
+    for (const auto &[key, dataset]: m_datasets.asKeyValueRange()) {
         if (levelMin <= dataset->difficulty() && dataset->difficulty() <= levelMax) {
             newLevels << key;
             dataset->setEnabled(true);
@@ -312,7 +379,6 @@ void ActivityInfo::enableDatasetsBetweenDifficulties(quint32 levelMin, quint32 l
         }
     }
     setCurrentLevels(newLevels);
-    ApplicationSettings::getInstance()->setCurrentLevels(m_name, m_currentLevels, false);
 }
 
 void ActivityInfo::addDataset(const QString &name, Dataset *dataset)
@@ -335,6 +401,12 @@ bool ActivityInfo::hasDataset() const
     return !m_levels.empty();
 }
 
+bool ActivityInfo::acceptDataset() const
+{
+    // This differs from hasDataset as an activity may accept dataset (multiple choice question) but don't have by default
+    return m_acceptDataset;
+}
+
 void ActivityInfo::resetLevels()
 {
     enableDatasetsBetweenDifficulties(1, 6);
