@@ -14,8 +14,9 @@
 #include <QString>
 #include <QStringList>
 #include <QQmlListProperty>
+#include <QtQml/qqmlregistration.h>
 #include "Dataset.h"
-
+#include <config.h>
 /**
  * @class ActivityInfo
  * @short A QML component holding meta information about an activity.
@@ -30,7 +31,9 @@
 class ActivityInfo : public QObject
 {
     Q_OBJECT
-
+#ifndef WITH_RCC
+    QML_ELEMENT
+#endif
     /**
      * Name of the main activity QML file.
      *
@@ -143,6 +146,12 @@ class ActivityInfo : public QObject
      */
     Q_PROPERTY(bool hasDataset READ hasDataset CONSTANT)
 
+    /**
+     * True if the activity can have datasets
+     * Needs to have levels declared in the ActivityInfo.qml file
+     */
+    Q_PROPERTY(bool acceptDataset READ acceptDataset CONSTANT)
+
 public:
     /// @cond INTERNAL_DOCS
     explicit ActivityInfo(QObject *parent = nullptr);
@@ -183,8 +192,11 @@ public:
     void setLevels(const QStringList &);
     QStringList currentLevels() const;
     void setCurrentLevels(const QStringList &);
+    QStringList ignoredLevels() const;
+    void setIgnoredLevels(const QStringList &);
     bool hasConfig() const;
     bool hasDataset() const;
+    bool acceptDataset() const;
     QQmlListProperty<Dataset> datasets();
     void fillDatasets(QQmlEngine *engine);
     void enableDatasetsBetweenDifficulties(quint32 levelMin, quint32 levelMax);
@@ -197,6 +209,11 @@ public:
      */
     void resetLevels();
 
+    /*
+     * Remove the dataset from the activity
+     */
+    void removeDataset(const QString &datasetName);
+
 Q_SIGNALS:
     void nameChanged();
     void sectionChanged();
@@ -216,6 +233,7 @@ Q_SIGNALS:
     void createdInVersionChanged();
     void levelsChanged();
     void currentLevelsChanged();
+    void ignoredLevelsChanged();
     void datasetsChanged();
     /// @endcond
 
@@ -236,8 +254,10 @@ private:
     bool m_favorite;
     bool m_enabled;
     int m_createdInVersion;
+    bool m_acceptDataset;
     QStringList m_levels;
     QStringList m_currentLevels;
+    QStringList m_ignoredLevels;
 
     /* The key is the name of the dataset */
     QMap<QString, Dataset *> m_datasets;
@@ -250,6 +270,8 @@ private:
      * Compute minimal and maximal difficulty depending on the current levels.
      */
     void computeMinMaxDifficulty();
+
+    friend class CoreActivityInfoTest;
 };
 
 #endif // ACTIVITYINFO_H
