@@ -9,12 +9,14 @@
  */
 #include "ActivityInfoTree.h"
 #include "ApplicationInfo.h"
+#include "File.h"
 
+#include <QDir>
+#include <QFile>
 #include <QtDebug>
 #include <QQmlProperty>
 #include <QQmlComponent>
 #include <QResource>
-#include <QStandardPaths>
 #include <QCoreApplication>
 #include <QTextStream>
 #include <QLatin1StringView>
@@ -165,7 +167,7 @@ void ActivityInfoTree::filterByTag(const QString &tag, const QString &category,
 bool ActivityInfoTree::launchedActivityMissGivenDifficulty() const{
     bool activityMissDifficulty = true;
     const auto constMenuTreeFull = m_menuTreeFull;
-    for (const auto &activity: constMenuTreeFull) {
+    for (const auto *activity: constMenuTreeFull) {
         if (activity->name() == m_startingActivity) {
             if (activity->maximalDifficulty() >= ApplicationSettings::getInstance()->filterLevelMin() &&
                 activity->minimalDifficulty() <= ApplicationSettings::getInstance()->filterLevelMax()) {
@@ -180,8 +182,8 @@ bool ActivityInfoTree::launchedActivityMissGivenDifficulty() const{
 void ActivityInfoTree::filterByDifficulty(quint32 levelMin, quint32 levelMax)
 {
     m_menuTree.removeIf([&](const ActivityInfo *activity) {
-                                 return activity->minimalDifficulty() < levelMin || activity->maximalDifficulty() > levelMax;
-                             });
+        return activity->minimalDifficulty() < levelMin || activity->maximalDifficulty() > levelMax;
+    });
 }
 
 void ActivityInfoTree::filterEnabledActivities(bool emitChanged)
@@ -244,7 +246,7 @@ void ActivityInfoTree::exportAsSQL()
 
     int i(0);
     const auto constMenuTree = m_menuTree;
-    for (const auto &activity: constMenuTree) {
+    for (const auto *activity: constMenuTree) {
         qtOut << "INSERT INTO activities VALUES(" << i++ << ", "
               << "'" << activity->name() << "', "
               << "'" << activity->section() << "', "
@@ -330,6 +332,10 @@ void ActivityInfoTree::initialize(QQmlEngine *engine)
 #endif
     }
 
+    if (ApplicationSettings::getInstance()->getUpdateToNewIgnoreLevels()) {
+        ApplicationSettings::getInstance()->removeLevelsSection();
+    }
+
     // In case we have asked for a specific activity to start but the activity does not exist, we reinitialise the value
     if (m_startingActivity == startingActivity) {
         m_startingActivity = "";
@@ -344,10 +350,11 @@ void ActivityInfoTree::initialize(QQmlEngine *engine)
 
 ActivityInfoTree *ActivityInfoTree::create(QQmlEngine *engine, QJSEngine *scriptEngine)
 {
+    Q_UNUSED(engine)
     Q_UNUSED(scriptEngine)
 
-    ActivityInfoTree *menuTree = getInstance();
-    return menuTree;
+    ActivityInfoTree *tree = getInstance();
+    return tree;
 }
 
 void ActivityInfoTree::registerResources()
@@ -409,7 +416,7 @@ QVariantList ActivityInfoTree::allCharacters()
 {
     QSet<QChar> keyboardChars;
     const auto constMenuTreeFull = m_menuTreeFull;
-    for (const auto &tree: constMenuTreeFull) {
+    for (const auto *tree: constMenuTreeFull) {
         const QString &title = tree->title();
         for (const QChar &letter: title) {
             if (letter.isLetterOrNumber() || letter == QLatin1Char('\'') || letter == QLatin1Char('-')) {
@@ -428,4 +435,80 @@ QVariantList ActivityInfoTree::allCharacters()
     return keyboardCharacters;
 }
 
+void ActivityInfoTree::createDataset(const QJsonObject &dataset)
+{
+    // Prefix dataset filename with "c-" to ensure it's not a restricted name on some platform
+    const QString datasetName("c-" + dataset["dataset_name"].toString());
+    const QString activityName(dataset["activity_name"].toString());
+    const QString datasetFolder(QStandardPaths::writableLocation(QStandardPaths::AppDataLocation) + "/" + activityName + '/' + datasetName);
+    QDir datasetDir(datasetFolder);
+    if (!datasetDir.exists()) {
+        datasetDir.mkpath(datasetFolder);
+    }
+    const QString filename = datasetFolder + "/Data.qml";
+    QString qmlFile = QString("import core 1.0\nData {\n    "
+                              "objective: \"%1\"\n    difficulty: %2\n    "
+                              "data: %3\n}\n")
+                          .arg(dataset["dataset_objective"].toString())
+                          .arg(dataset["dataset_difficulty"].toInt())
+                          .arg(dataset["dataset_content"].toString());
+
+    File datasetFile;
+    qDebug() << "Write" << qmlFile << "in" << filename;
+    datasetFile.write(qmlFile, filename);
+
+    const auto &constMenuTreeFull = m_menuTreeFull;
+    QQmlEngine *engine = qmlEngine(this);
+
+    for (const auto &activity: constMenuTreeFull) {
+        if (activity->name().split("/").at(0) == activityName) {
+            activity->fillDatasets(engine);
+            break;
+        }
+    }
+}
+
+void ActivityInfoTree::removeDataset(const QJsonObject &dataset)
+{
+    qDebug() << "ActivityInfoTree::removeDataset" << dataset;
+    const QString datasetName("c-" + dataset["dataset_name"].toString());
+    const QString activityName(dataset["activity_name"].toString());
+    const QString datasetFolder(QStandardPaths::writableLocation(QStandardPaths::AppDataLocation) + "/" + activityName + '/' + datasetName);
+    QDir datasetDir(datasetFolder);
+    if (datasetDir.exists()) {
+        datasetDir.removeRecursively();
+    }
+
+    const auto &constMenuTreeFull = m_menuTreeFull;
+    QQmlEngine *engine = qmlEngine(this);
+
+    for (const auto &activity: constMenuTreeFull) {
+        if (activity->name().split("/").at(0) == activityName) {
+            activity->removeDataset(datasetName);
+            activity->fillDatasets(engine);
+
+            if (QStringList ignoredLevels = ApplicationSettings::getInstance()->ignoredLevels(activityName); ignoredLevels.contains(datasetName)) {
+                ignoredLevels.removeOne(datasetName);
+                ApplicationSettings::getInstance()->setIgnoredLevels(activityName, ignoredLevels);
+            }
+            break;
+        }
+    }
+}
+
+void ActivityInfoTree::removeAllLocalDatasets()
+{
+    const QString datasetRootFolder(QStandardPaths::writableLocation(QStandardPaths::AppDataLocation));
+    QDir datasetsDir(datasetRootFolder);
+    for (const QFileInfo &activityFolder: datasetsDir.entryInfoList(QDir::AllDirs| QDir::NoDotAndDotDot)) {
+        QJsonObject dataset;
+        dataset["activity_name"] = activityFolder.fileName();
+        QDir activityDir(activityFolder.absoluteFilePath());
+        for (const QFileInfo &datasetFolder: activityDir.entryInfoList(QDir::AllDirs | QDir::NoDotAndDotDot)) {
+            dataset["dataset_name"] = datasetFolder.fileName();
+            removeDataset(dataset);
+        }
+    }
+}
+
 #include "moc_ActivityInfoTree.cpp"
