@@ -61,6 +61,9 @@ ApplicationInfo::ApplicationInfo(QObject *parent) :
 
     QRect rect = qApp->primaryScreen()->geometry();
     m_ratio = qMin(qMax(rect.width(), rect.height()) / 800., qMin(rect.width(), rect.height()) / 520.);
+#if defined(UBUNTUTOUCH)
+    m_fontRatio = floor(m_ratio * 10) / 10;
+#else
     // calculate a factor for font-scaling, cf.
     // https://doc.qt.io/qt-5/scalability.html#calculating-scaling-ratio
     qreal refDpi = 216.;
@@ -69,10 +72,6 @@ ApplicationInfo::ApplicationInfo(QObject *parent) :
     qreal height = qMax(rect.width(), rect.height());
     qreal width = qMin(rect.width(), rect.height());
     qreal dpi = qApp->primaryScreen()->logicalDotsPerInch();
-
-#if defined(UBUNTUTOUCH)
-    m_fontRatio = floor(m_ratio * 10) / 10;
-#else
     m_fontRatio = qMax(qreal(1.0), qMin(height * refDpi / (dpi * refHeight), width * refDpi / (dpi * refWidth)));
 #endif
     m_isPortraitMode = m_isMobile ? rect.height() > rect.width() : false;
@@ -225,20 +224,19 @@ void ApplicationInfo::notifyFullscreenChanged()
 }
 
 // Would be better to create a component importing Box2D 2.0 using QQmlContext and test if it exists but it does not work.
-void ApplicationInfo::setBox2DInstalled(QQmlEngine &engine)
+void ApplicationInfo::setBox2DInstalled()
 {
-    m_engine = &engine;
     /*
       QQmlContext *context = new QQmlContext(engine.rootContext());
       context->setContextObject(&myDataSet);
 
       QQmlComponent component(&engine);
-      component.setData("import QtQuick 2.12\nimport Box2D 2.0\nItem { }", QUrl());
+      component.setData("import QtQuick\nimport Box2D 2.0\nItem { }", QUrl());
       component.create(context);
       box2dInstalled = (component != nullptr);
     */
     bool box2dInstalled = false;
-    const QStringList importPathList = engine.importPathList();
+    const QStringList importPathList = m_engine->importPathList();
     for (const QString &folder: importPathList) {
         if (QDir(folder).entryList().contains(QLatin1String("Box2D.2.0"))) {
             if (QDir(folder + "/Box2D.2.0").entryList().contains("qmldir")) {
@@ -252,6 +250,18 @@ void ApplicationInfo::setBox2DInstalled(QQmlEngine &engine)
     Q_EMIT isBox2DInstalledChanged();
 }
 
+void ApplicationInfo::setServerConnectionAccepted(bool connectionAccepted)
+{
+    m_serverConnectionAccepted = connectionAccepted;
+    Q_EMIT serverConnectionAcceptedChanged();
+}
+
+void ApplicationInfo::setServerStatusColor(const QString &statusColor)
+{
+    m_serverStatusColor = statusColor;
+    Q_EMIT serverStatusColorChanged();
+}
+
 // return the shortest possible locale name for the given locale, describing
 // a unique voices dataset
 QString ApplicationInfo::getVoicesLocale(const QString &locale)
@@ -287,16 +297,20 @@ QVariantList ApplicationInfo::localeSort(QVariantList list,
     return list;
 }
 
-bool ApplicationInfo::loadAndroidTranslation(const QString &locale)
+bool ApplicationInfo::loadAndroidTranslation(const QString &applicationName, const QString &locale)
 {
-    QFile file("assets:/share/GCompris/gcompris_" + locale + ".qm");
+    QFile file("assets:/share/GCompris/" + applicationName + "_" + locale + ".qm");
 
     if (!file.exists()) {
-        qDebug() << "file assets:/share/GCompris/gcompris_" << locale << ".qm does not exist";
+        qDebug() << "file assets:/share/GCompris/" + applicationName + "_" + locale + ".qm does not exist";
         return false;
     }
 
-    file.open(QIODevice::ReadOnly);
+    bool isOpened = file.open(QIODevice::ReadOnly);
+    if (!isOpened) {
+        qDebug() << "Unable to open " << file.fileName();
+        return false;
+    }
     QDataStream in(&file);
 
     qint64 fileSize = file.size();
@@ -304,7 +318,7 @@ bool ApplicationInfo::loadAndroidTranslation(const QString &locale)
 
     in.readRawData((char *)data, fileSize);
 
-    if (!m_translator.load(data, fileSize)) {
+    if (!m_translators[applicationName].load(data, fileSize)) {
         qDebug() << "Unable to load translation for locale " << locale << ", use en_US by default";
         free(data);
         return false;
@@ -314,36 +328,35 @@ bool ApplicationInfo::loadAndroidTranslation(const QString &locale)
 }
 
 /**
- * Checks if the locale is supported. Locale may have been removed because
+ * Returns a list of supported locales. Locale may have been removed because
  * translation progress was not enough or invalid language put in configuration.
  */
-bool ApplicationInfo::isSupportedLocale(const QString &locale)
+QStringList ApplicationInfo::supportedLocales()
 {
-    bool isSupported = false;
+    QStringList supportedLocales;
     QQmlEngine engine;
     QQmlComponent component(&engine, QUrl("qrc:/gcompris/src/core/LanguageList.qml"));
     QObject *object = component.create();
     if (!object) {
-        qWarning() << "isSupportedLocale:" << component.errors();
-        return false;
+        qWarning() << "supportedLocales:" << component.errors();
+        return supportedLocales;
     }
     QVariant variant = object->property("languages");
     QJSValue languagesList = variant.value<QJSValue>();
     const int length = languagesList.property("length").toInt();
     for (int i = 0; i < length; ++i) {
-        if (languagesList.property(i).property("locale").toString() == locale) {
-            isSupported = true;
-        }
+        supportedLocales << languagesList.property(i).property("locale").toString();
     }
     delete object;
-    return isSupported;
+    return supportedLocales;
 }
 
 // Return the locale
-QString ApplicationInfo::loadTranslation(const QString &requestedLocale)
+QString ApplicationInfo::loadTranslation(const QString &applicationName, const QString &requestedLocale)
 {
     QString locale = requestedLocale;
-    if (!isSupportedLocale(locale)) {
+    QStringList locales = supportedLocales();
+    if (!locales.contains(locale)) {
         qDebug() << "locale" << locale << "not supported, defaulting to" << GC_DEFAULT_LOCALE;
         locale = GC_DEFAULT_LOCALE;
         ApplicationSettings::getInstance()->setLocale(locale);
@@ -360,47 +373,57 @@ QString ApplicationInfo::loadTranslation(const QString &requestedLocale)
     locale.remove(".UTF-8");
 
 #if defined(Q_OS_ANDROID)
-    if (!loadAndroidTranslation(locale))
-        loadAndroidTranslation(ApplicationInfo::localeShort(locale));
+    if (!loadAndroidTranslation(applicationName, locale))
+        loadAndroidTranslation(applicationName, ApplicationInfo::localeShort(locale));
 #else
 
 #if (defined(Q_OS_LINUX) || defined(Q_OS_UNIX))
     // only useful for translators: load from $application_dir/../share/... if exists as it is where kde scripts install translations
-    if (m_translator.load("gcompris_qt.qm", QString("%1/../share/locale/%2/LC_MESSAGES").arg(QCoreApplication::applicationDirPath(), locale))) {
+    if (m_translators[applicationName].load(applicationName, QString("%1/../share/locale/%2/LC_MESSAGES").arg(QCoreApplication::applicationDirPath(), locale))) {
         qDebug() << "load translation for locale " << locale << " in " << QString("%1/../share/locale/%2/LC_MESSAGES").arg(QCoreApplication::applicationDirPath(), locale);
     }
-    else if (m_translator.load("gcompris_qt.qm", QString("%1/../share/locale/%2/LC_MESSAGES").arg(QCoreApplication::applicationDirPath(), locale.split('_')[0]))) {
+    else if (m_translators[applicationName].load(applicationName + ".qm", QString("%1/../share/locale/%2/LC_MESSAGES").arg(QCoreApplication::applicationDirPath(), locale.split('_')[0]))) {
         qDebug() << "load translation for locale " << locale << " in " << QString("%1/../share/locale/%2/LC_MESSAGES").arg(QCoreApplication::applicationDirPath(), locale.split('_')[0]);
     }
     else
 #endif
-        if (!m_translator.load("gcompris_" + locale, QString("%1/%2/translations").arg(QCoreApplication::applicationDirPath(), GCOMPRIS_DATA_FOLDER))) {
-        qDebug() << "Unable to load translation for locale " << locale << ", use en_US by default";
-    }
+        if (!m_translators[applicationName].load(applicationName + "_" + locale, QString("%1/%2/translations").arg(QCoreApplication::applicationDirPath(), GCOMPRIS_DATA_FOLDER))) {
+            qDebug() << "Unable to load translation for locale " << locale << ", use en_US by default";
+        }
 #endif
-    return locale;
-}
 
-void ApplicationInfo::switchLocale()
-{
-    switchLocale(ApplicationSettings::getInstance()->locale());
+    return locale;
 }
 
 void ApplicationInfo::switchLocale(const QString &locale)
 {
-    qDebug() << "switch locale to" << locale;
-
-    // Remove previous translation
-    QCoreApplication::removeTranslator(&m_translator);
-    loadTranslation(locale);
-    // Apply translation
-    QCoreApplication::installTranslator(&m_translator);
+    for (const auto &[applicationName, translator] : m_translators) {
+        switchLocale(applicationName, locale, false);
+    }
 
     if (m_engine) {
         m_engine->retranslate();
     }
 }
 
+void ApplicationInfo::switchLocale(const QString &application, const QString &locale, bool forceRetranslate)
+{
+    // Remove previous translation
+    QCoreApplication::removeTranslator(&m_translators[application]);
+    loadTranslation(application, locale);
+    // Apply translation
+    QCoreApplication::installTranslator(&m_translators[application]);
+
+    if (forceRetranslate && m_engine) {
+        m_engine->retranslate();
+    }
+}
+
+void ApplicationInfo::setEngine(QQmlEngine &engine)
+{
+    m_engine = &engine;
+}
+
 ApplicationInfo *ApplicationInfo::create(QQmlEngine *engine,
                                          QJSEngine *scriptEngine)
 {
