@@ -21,6 +21,9 @@
 #include <QTranslator>
 #include <QtQml/qqmlregistration.h>
 
+// Can be removed when Qt6.9 is minimum version
+#include <QVersionNumber>
+
 class QQmlEngine;
 class QQuickWindow;
 
@@ -116,6 +119,12 @@ class ApplicationInfo : public QObject
      */
     Q_PROPERTY(QString QTVersion READ QTVersion CONSTANT)
 
+    /**
+     * Qt minor version int (runtime).
+     * only use to get Qt < 6.9 for QtGraphs switch
+     */
+    Q_PROPERTY(int QTMinorVersion READ QTMinorVersion CONSTANT)
+
     /**
      * OpenSSL version string (runtime).
      */
@@ -284,12 +293,15 @@ public:
      * Switch the locale in GCompris to the new one.
      * The locale will be fetched from ApplicationSettings if not passed in parameter
      */
-    void switchLocale();
-    void switchLocale(const QString &locale);
+    Q_INVOKABLE void switchLocale(const QString &locale = ApplicationSettings::getInstance()->locale());
+    void switchLocale(const QString &application, const QString &locale, bool forceRetranslate = true);
+    QStringList supportedLocales();
 
     static QString GCVersion() { return VERSION; }
     static int GCVersionCode() { return VERSION_CODE; }
     static QString QTVersion() { return qVersion(); }
+    // Only used for the switch to QtGraphs, can be removed after Qt 6.9 minimum
+    static int QTMinorVersion() { return QVersionNumber::fromString(qVersion()).minorVersion(); }
     static QString OpenSSLVersion() { return QSslSocket::sslLibraryVersionString(); }
     static QString CompressedAudio() { return COMPRESSED_AUDIO; }
     static bool isDownloadAllowed() { return QString(DOWNLOAD_ALLOWED) == "ON"; }
@@ -297,7 +309,21 @@ public:
     void setUseSoftwareRenderer(bool useSoftwareRenderer) { m_useSoftwareRenderer = useSoftwareRenderer; }
 
     bool isBox2DInstalled() const { return m_isBox2DInstalled; }
-    void setBox2DInstalled(QQmlEngine &engine);
+    void setBox2DInstalled();
+
+    void setEngine(QQmlEngine &engine);
+
+    /**
+     * Set to true after first connection to teacher's server, to indicate that the server status button should be visible.
+     */
+    Q_PROPERTY(bool serverConnectionAccepted MEMBER m_serverConnectionAccepted WRITE setServerConnectionAccepted NOTIFY serverConnectionAcceptedChanged)
+    Q_INVOKABLE void setServerConnectionAccepted(bool connectionAccepted);
+
+    /**
+     * Set the color of serverStatus button in the bar.
+     */
+    Q_PROPERTY(QString serverStatusColor MEMBER m_serverStatusColor WRITE setServerStatusColor NOTIFY serverStatusColorChanged)
+    Q_INVOKABLE void setServerStatusColor(const QString &statusColor);
 
     /**
      * Returns the native screen orientation.
@@ -446,11 +472,13 @@ Q_SIGNALS:
     void fullscreenChanged();
     void useSoftwareRendererChanged();
     void isBox2DInstalledChanged();
+    void serverConnectionAcceptedChanged();
+    void serverStatusColorChanged();
 
 private:
     static ApplicationInfo *m_instance;
     QQmlEngine *m_engine { nullptr };
-    QTranslator m_translator;
+    std::unordered_map<QString, QTranslator> m_translators;
     int m_applicationWidth;
     Platform m_platform;
     bool m_isPortraitMode;
@@ -459,6 +487,8 @@ private:
     bool m_isBox2DInstalled;
     qreal m_ratio;
     qreal m_fontRatio;
+    bool m_serverConnectionAccepted = false;
+    QString m_serverStatusColor = "red";
 
     // Symbols fonts that user can't see
     QStringList m_excludedFonts;
@@ -467,9 +497,8 @@ private:
 
     static QQuickWindow *m_window;
 
-    bool loadAndroidTranslation(const QString &locale);
-    bool isSupportedLocale(const QString &locale);
-    QString loadTranslation(const QString &requestedLocale);
+    bool loadAndroidTranslation(const QString &application, const QString &locale);
+    QString loadTranslation(const QString &application, const QString &requestedLocale);
 };
 
 #endif // APPLICATIONINFO_H
