@@ -30,6 +30,8 @@ namespace {
     const char *INTERNAL_GROUP_KEY = "Internal";
     const char *FAVORITE_GROUP_KEY = "Favorite";
     const char *LEVELS_GROUP_KEY = "Levels";
+    const char *IGNORED_LEVELS_GROUP_KEY = "IgnoredLevels";
+    const char *TEACHER_GROUP_KEY = "Teacher";
 
     const char *FULLSCREEN_KEY = "fullscreen";
     const char *PREVIOUS_HEIGHT_KEY = "previousHeight";
@@ -51,6 +53,8 @@ namespace {
     const char *USERDATA_PATH_KEY = "userDataPath";
     const char *RENDERER_KEY = "renderer";
 
+    const char *TEACHER_ID_KEY = "teacherId";
+    const char *TEACHER_PORT_KEY = "teacherPort";
     const char *EXE_COUNT_KEY = "exeCount";
     const char *LAST_GC_VERSION_RAN = "lastGCVersionRan";
 
@@ -64,6 +68,7 @@ namespace {
     const char *DEFAULT_CURSOR = "defaultCursor";
     const char *NO_CURSOR = "noCursor";
     const char *KIOSK_KEY = "kiosk";
+    const char *HOME_BUTTON_VISIBLE_KEY = "homeButtonVisible";
     const char *SECTION_VISIBLE = "sectionVisible";
     const char *EXIT_CONFIRMATION = "exitConfirmation";
 
@@ -110,6 +115,7 @@ ApplicationSettings::ApplicationSettings(const QString &configPath, QObject *par
 #else
     m_isKioskMode = m_config.value(KIOSK_KEY, false).toBool();
 #endif
+    m_isHomeButtonVisible = m_config.value(HOME_BUTTON_VISIBLE_KEY, true).toBool();
 
     m_sectionVisible = m_config.value(SECTION_VISIBLE, true).toBool();
     m_exitConfirmation = m_config.value(EXIT_CONFIRMATION, ApplicationInfo::getInstance()->isMobile() ? true : false).toBool();
@@ -141,6 +147,12 @@ ApplicationSettings::ApplicationSettings(const QString &configPath, QObject *par
     m_renderer = m_config.value(RENDERER_KEY, GRAPHICAL_RENDERER).toString();
     m_config.endGroup();
 
+    // teacher group
+    m_config.beginGroup(TEACHER_GROUP_KEY);
+    m_teacherId = m_config.value(TEACHER_ID_KEY, "").toString();
+    m_teacherPort = m_config.value(TEACHER_PORT_KEY, "65524").toString();
+    m_config.endGroup();
+
     // internal group
     m_config.beginGroup(INTERNAL_GROUP_KEY);
     m_exeCount = m_config.value(EXE_COUNT_KEY, 0).toUInt();
@@ -166,6 +178,7 @@ ApplicationSettings::ApplicationSettings(const QString &configPath, QObject *par
     connect(this, &ApplicationSettings::sectionVisibleChanged, this, &ApplicationSettings::notifySectionVisibleChanged);
     connect(this, &ApplicationSettings::exitConfirmationChanged, this, &ApplicationSettings::notifyExitConfirmationChanged);
     connect(this, &ApplicationSettings::kioskModeChanged, this, &ApplicationSettings::notifyKioskModeChanged);
+    connect(this, &ApplicationSettings::homeButtonVisibleChanged, this, &ApplicationSettings::notifyHomeButtonVisibleChanged);
     connect(this, &ApplicationSettings::downloadServerUrlChanged, this, &ApplicationSettings::notifyDownloadServerUrlChanged);
     connect(this, &ApplicationSettings::cachePathChanged, this, &ApplicationSettings::notifyCachePathChanged);
     connect(this, &ApplicationSettings::userDataPathChanged, this, &ApplicationSettings::notifyUserDataPathChanged);
@@ -173,10 +186,16 @@ ApplicationSettings::ApplicationSettings(const QString &configPath, QObject *par
     connect(this, &ApplicationSettings::exeCountChanged, this, &ApplicationSettings::notifyExeCountChanged);
     connect(this, &ApplicationSettings::barHiddenChanged, this, &ApplicationSettings::notifyBarHiddenChanged);
     connect(this, &ApplicationSettings::lastGCVersionRanChanged, this, &ApplicationSettings::notifyLastGCVersionRanChanged);
+    connect(this, &ApplicationSettings::teacherIdChanged, this, &ApplicationSettings::notifyTeacherIdChanged);
+    connect(this, &ApplicationSettings::teacherPortChanged, this, &ApplicationSettings::notifyTeacherPortChanged);
     connect(this, &ApplicationSettings::backgroundMusicVolumeChanged, this, &ApplicationSettings::notifyBackgroundMusicVolumeChanged);
     connect(this, &ApplicationSettings::audioEffectsVolumeChanged, this, &ApplicationSettings::notifyAudioEffectsVolumeChanged);
 
-    connect(this, &ApplicationSettings::localeChanged, ApplicationInfo::getInstance(), qOverload<>(&ApplicationInfo::switchLocale));
+    if (m_lastGCVersionRan < ApplicationInfo::GCVersionCode() && m_lastGCVersionRan < 260000) {
+        m_updateToNewIgnoreLevels = true;
+    }
+
+    connect(this, &ApplicationSettings::localeChanged, ApplicationInfo::getInstance(), []() { ApplicationInfo::getInstance()->switchLocale(); } );
 }
 
 ApplicationSettings::~ApplicationSettings()
@@ -202,6 +221,7 @@ ApplicationSettings::~ApplicationSettings()
         m_config.setValue(FILTER_LEVEL_MAX, m_filterLevelMax);
     }
     m_config.setValue(KIOSK_KEY, m_isKioskMode);
+    m_config.setValue(HOME_BUTTON_VISIBLE_KEY, m_isHomeButtonVisible);
     m_config.setValue(SECTION_VISIBLE, m_sectionVisible);
     m_config.setValue(EXIT_CONFIRMATION, m_exitConfirmation);
     m_config.setValue(DEFAULT_CURSOR, m_defaultCursor);
@@ -219,6 +239,12 @@ ApplicationSettings::~ApplicationSettings()
     m_config.setValue(RENDERER_KEY, m_renderer);
     m_config.endGroup();
 
+    // teacher group
+    m_config.beginGroup(TEACHER_GROUP_KEY);
+    m_config.setValue(TEACHER_ID_KEY, m_teacherId);
+    m_config.setValue(TEACHER_PORT_KEY, m_teacherPort);
+    m_config.endGroup();
+
     // internal group
     m_config.beginGroup(INTERNAL_GROUP_KEY);
     m_config.setValue(EXE_COUNT_KEY, m_exeCount);
@@ -359,6 +385,12 @@ void ApplicationSettings::notifyKioskModeChanged()
     qDebug() << "notifyKioskMode: " << m_isKioskMode;
 }
 
+void ApplicationSettings::notifyHomeButtonVisibleChanged()
+{
+    updateValueInConfig(GENERAL_GROUP_KEY, HOME_BUTTON_VISIBLE_KEY, m_isHomeButtonVisible);
+    qDebug() << "notifyHomeButtonVisible: " << m_isHomeButtonVisible;
+}
+
 void ApplicationSettings::notifySectionVisibleChanged()
 {
     updateValueInConfig(GENERAL_GROUP_KEY, SECTION_VISIBLE, m_sectionVisible);
@@ -376,6 +408,18 @@ void ApplicationSettings::notifyDownloadServerUrlChanged()
     qDebug() << "downloadServerUrl set to: " << m_downloadServerUrl;
 }
 
+void ApplicationSettings::notifyTeacherIdChanged()
+{
+    updateValueInConfig(TEACHER_GROUP_KEY, TEACHER_ID_KEY, m_teacherId);
+    qDebug() << "teacherId set to: " << m_teacherId;
+}
+
+void ApplicationSettings::notifyTeacherPortChanged()
+{
+    updateValueInConfig(TEACHER_GROUP_KEY, TEACHER_PORT_KEY, m_teacherPort);
+    qDebug() << "teacherPort set to: " << m_teacherPort;
+}
+
 void ApplicationSettings::notifyCachePathChanged()
 {
     updateValueInConfig(ADMIN_GROUP_KEY, CACHE_PATH_KEY, m_cachePath);
@@ -468,11 +512,27 @@ QStringList ApplicationSettings::currentLevels(const QString &activity)
     return level;
 }
 
+void ApplicationSettings::setIgnoredLevels(const QString &activity, const QStringList &level, bool sync)
+{
+    if (!m_filterLevelOverridedByCommandLineOption) {
+        updateValueInConfig(IGNORED_LEVELS_GROUP_KEY, activity, level, sync);
+    }
+}
+
+QStringList ApplicationSettings::ignoredLevels(const QString &activity)
+{
+    m_config.beginGroup(IGNORED_LEVELS_GROUP_KEY);
+    QStringList level = m_config.value(activity, QStringList()).toStringList();
+    m_config.endGroup();
+    return level;
+}
+
 template <class T>
 void ApplicationSettings::updateValueInConfig(const QString &group,
                                               const QString &key, const T &value, bool sync)
 {
     m_config.beginGroup(group);
+
     m_config.setValue(key, value);
     m_config.endGroup();
     if (sync) {
@@ -505,6 +565,13 @@ bool ApplicationSettings::useExternalWordset()
     return DownloadManager::getInstance()->isDataRegistered("words-webp");
 }
 
+void ApplicationSettings::removeLevelsSection()
+{
+    m_config.beginGroup(LEVELS_GROUP_KEY);
+    m_config.remove("");
+    m_config.endGroup();
+}
+
 ApplicationSettings *ApplicationSettings::create(QQmlEngine *engine,
                                                  QJSEngine *scriptEngine)
 {
