@@ -17,7 +17,7 @@
  * FIXME: how to include this file in kgenapidox's output?
  */
 .pragma library
-.import QtQml 2.12 as Qml
+.import QtQml as Qml
 .import core 1.0 as GCompris
 
 /**
@@ -128,7 +128,7 @@ function showMessageDialog(parent, informativeText,
                            closeCallback) {
     //console.debug("Core.showMessageDialog: parent=" + parent + " backtrace="); console.trace();
     var qmlStr =
-          'import QtQuick 2.12\n'
+          'import QtQuick\n'
         + 'GCDialog {\n'
         + '    message: "' + informativeText + '"\n'
         + '    button1Text: "' + button1Text + '"\n'
@@ -211,7 +211,7 @@ function showDownloadDialog(parent, properties) {
  * Helper checking for availability of audio voices for the current locale and
  * informing the user in case they're missing.
  *
- * Can be used by acitivities that depend on audio voices to inform the user
+ * Can be used by activities that depend on audio voices to inform the user
  * of missing resources during startup.
  *
  * @param parent Parent QML object.
@@ -264,7 +264,7 @@ function quit(parent)
         });
         dialog.finished.connect(function() {Qt.quit();});
     } else if (GCompris.ApplicationSettings.exitConfirmation) {
-        // prevent the user from quitting accidentially by clicking back too often:
+        // prevent the user from quitting accidentally by clicking back too often:
         showMessageDialog(parent,
                 qsTr("Quit?") +
                 '\n' +
@@ -311,7 +311,9 @@ function convertNumberToLocaleString(decimalNumber, locale = GCompris.Applicatio
     // Special case for Arabic, we still want to use Arabic numerals, not Eastern Arabic numerals
     // For now, we consider dot separated numbers for Arabic
     var localeToConvertTo = (locale.startsWith("ar") ? "he" : locale);
-    return decimalNumber.toLocaleString(Qt.locale(localeToConvertTo), format, precision);
+    var qtLocale = Qt.locale(localeToConvertTo);
+    qtLocale.numberOptions = Qml.Locale.OmitGroupSeparator;
+    return decimalNumber.toLocaleString(qtLocale, format, precision);
 }
 
 function convertNumberToLocaleCurrencyString(number, locale) {
@@ -363,6 +365,7 @@ function fitItems(x_, y_, n_, extra_) {
     
     return Math.max(cell_size1, cell_size2);
 }
+
 /**
  * Function that returns a clamped number between min_ and max_
  *
@@ -373,3 +376,28 @@ function fitItems(x_, y_, n_, extra_) {
 function clamp(x_, min_, max_) {
     return Math.min(Math.max(x_, min_), max_);
 }
+
+/**
+   First sort the added datasets (which should be words), then sort all the internal levels (which are numbers)
+*/
+function sortLevels(chosenLevels) {
+    chosenLevels.sort(function(a, b) {
+        var first = parseInt(a)
+        var second = parseInt(b)
+        if (!first && !second) { // both are strings
+            return a.localeCompare(b)
+        }
+        else if (!first) { // first is a string
+            return -1
+        }
+        else if (!second) { // second is a string
+            return 1
+        }
+        // both are numbers
+        return first - second
+    });
+}
+
+function getPasswordImages() {
+    return [ "apple", "banana", "cherries", "lemon", "orange", "pear", "pineapple", "plum" ]
+}
