@@ -8,7 +8,11 @@
  *   SPDX-License-Identifier: GPL-3.0-or-later
  */
 #include <QtDebug>
+#if QT_VERSION >= QT_VERSION_CHECK(6, 9, 0)
+#include <QGuiApplication>
+#else
 #include <QApplication>
+#endif
 #include <QQuickWindow>
 #include <QQmlApplicationEngine>
 #include <QStandardPaths>
@@ -27,12 +31,20 @@
 #include "ActivityInfoTree.h"
 #include "DownloadManager.h"
 
+#include "ClientNetworkMessages.h"
+#include "netconst.h"
+
 int main(int argc, char *argv[])
 {
     // Disable it because we already support HDPI display natively
     qunsetenv("QT_DEVICE_PIXEL_RATIO");
 
+#if QT_VERSION >= QT_VERSION_CHECK(6, 9, 0)
+    QGuiApplication app(argc, argv);
+#else
     QApplication app(argc, argv);
+#endif
+
 #if defined(UBUNTUTOUCH)
     app.setOrganizationName("org.kde.gcompris");
 #else
@@ -130,6 +142,18 @@ int main(int argc, char *argv[])
                                       QObject::tr("Specify on which level to start the activity. Only used when --launch option is used."), "startLevel");
     parser.addOption(clStartOnLevel);
 
+    QCommandLineOption clLocale("locale",
+                              QObject::tr("Specify the locale when starting GCompris."), "locale");
+    parser.addOption(clLocale);
+
+    QCommandLineOption clHideHomeButton("hide-home-button",
+                              QObject::tr("Hide the Home button in the bar."));
+    parser.addOption(clHideHomeButton);
+
+    QCommandLineOption clShowHomeButton("show-home-button",
+                              QObject::tr("Show the Home button in the bar (default)."));
+    parser.addOption(clShowHomeButton);
+
     parser.process(app);
 
 #ifdef WITH_RCC
@@ -192,6 +216,25 @@ int main(int argc, char *argv[])
     if (parser.isSet(clWithKioskMode)) {
         ApplicationSettings::getInstance()->setKioskMode(true);
     }
+    if (parser.isSet(clHideHomeButton)) {
+        ApplicationSettings::getInstance()->setHomeButtonVisible(false);
+    }
+    if (parser.isSet(clShowHomeButton)) {
+        ApplicationSettings::getInstance()->setHomeButtonVisible(true);
+    }
+    if (parser.isSet(clLocale)) {
+        QString locale = parser.value(clLocale);
+        if (locale != "system") {
+            locale += QStringLiteral(".UTF-8");
+        }
+        QStringList allLocales = ApplicationInfo::getInstance()->supportedLocales();
+        if (!allLocales.contains(locale)) {
+            qDebug() << "supported locales are:" << allLocales.replaceInStrings(".UTF-8", "").join(", ");
+        }
+        else {
+            ApplicationSettings::getInstance()->setLocale(locale);
+        }
+    }
     // This will be removed later, for now, it is ignored if --renderer option is set
     if (parser.isSet(clSoftwareRenderer)) {
         ApplicationSettings::getInstance()->setRenderer(QStringLiteral("software"));
@@ -250,11 +293,24 @@ int main(int argc, char *argv[])
 
     // Load translations
     QString locale = config.value("General/locale", GC_DEFAULT_LOCALE).toString();
-    ApplicationInfo::getInstance()->switchLocale(locale);
+    ApplicationInfo::getInstance()->switchLocale(QStringLiteral("gcompris_qt"), locale);
+
+    qmlRegisterUncreatableMetaObject(
+      netconst::staticMetaObject,   // meta object created by Q_NAMESPACE macro
+      "GCompris",                   // import statement (can be any string)
+      1, 0,                         // major and minor version of the import
+      "NetConst",                   // name in QML (does not have to match C++ name)
+      "Error: only enums"           // error in case someone tries to create a MyNamespace object
+    );
 
     QQmlApplicationEngine engine;
+
+    ClientNetworkMessages clientNetworkMessages;
+    engine.rootContext()->setContextProperty("clientNetworkMessages", &clientNetworkMessages);
+
     QObject::connect(&engine, &QQmlApplicationEngine::quit, DownloadManager::getInstance(),
                      &DownloadManager::shutdown);
+
     // add import path for shipped qml modules:
     engine.addImportPath(QStringLiteral("%1/../lib/qml")
                              .arg(QCoreApplication::applicationDirPath()));
@@ -264,7 +320,8 @@ int main(int argc, char *argv[])
     engine.addImportPath(QStringLiteral("assets:/"));
 #endif
 
-    ApplicationInfo::getInstance()->setBox2DInstalled(engine);
+    ApplicationInfo::getInstance()->setEngine(engine);
+    ApplicationInfo::getInstance()->setBox2DInstalled();
 
     // We load the main file after checking for box2d to avoid computing multiple times the menu
     engine.load(QUrl("qrc:/gcompris/src/core/main.qml"));
