@@ -9,7 +9,7 @@ import json
 import sys
 
 if len(sys.argv) != 2:
-    print "Usage: validate-json.py json_file"
+    print("Usage: validate-json.py json_file")
     sys.exit(1)
 
 inf=sys.argv[1]
@@ -17,9 +17,9 @@ inf=sys.argv[1]
 with open(inf) as data_file:
     try:
         data = json.load(data_file)
-        print "Processing OK " + inf
+        print("Processing OK " + inf)
     except ValueError as e:
-        print dir(e)
-        print "Processing KO " + inf
-        print "Parser error: {0}".format(e.message)
+        print(dir(e))
+        print("Processing KO " + inf)
+        print("Parser error: {0}".format(e.message))
 
